.. :changelog:

History
-------

0.2.0 (2015-10-03)
++++++++++++++++++

* Add support for using request in extracting metadata
* Add one (optional) argument to class method call.
* Add support for editorconfig
* Add get_meta method to allow customising metadata
* Use META_SITE_PROTOCOL when generating full URL
* Extend documentation
* Clean up the code
* Use ``build_absolute_url`` instead of ``make_full_url``

0.1.1 (2014-06-20)
++++++++++++++++++

* Add ``make_full_url`` method to retrieve complete object URL.

0.1.0 (2014-04-19)
++++++++++++++++++

* First release on PyPI.
